@@ -136,17 +136,19 @@ class NoseXML(Plugin):
 			frameElement.set("function", str(func))
 			frameElement.text = text
 
-	def addError(self, test, capture):
+	def addError(self, test, error, capture):
 		"""
 		Test errored. Not sure what causes this
 		
 		<test status="error" id="package.module.class.function">
+			<error>something</error>
 			<capture>Who knows what generates one of these?</capture>
 		</test>
 		"""
 		e = ET.SubElement(self.root, "test")
 		e.set("status", "error")
 		e.set("id", test.id())
+		ET.SubElement(e, "error").text = str(error)
 		ET.SubElement(e, "capture").text = capture
 	
 	def addDeprecated(self, test):
